CardIdentifierSetCollectorNumber class

Finds a card with the specified set and collector_number.

Implemented types
Annotations
  • @JsonSerializable.new(createToJson: true)

Constructors

CardIdentifierSetCollectorNumber(String set, String collectorNumber)
Constructs a CardIdentifierSetCollectorNumber by settings its properties.
const
CardIdentifierSetCollectorNumber.fromJson(Map<String, dynamic> json)
Constructs a CardIdentifierSetCollectorNumber from JSON.
factory

Properties

collectorNumber → String
The collector_number of a card.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set → String
The set code of a card.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts a CardIdentifierSetCollectorNumber to JSON.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited