Migration class

A Migration object helps to reconcile downstream data that may have been synced or imported from Scryfall.

In rare instances, it may be discovered that a card in the Scryfall database does not really exist or has been removed from a digital game permanantly.

Annotations
  • @JsonSerializable.new()

Constructors

Migration({required String id, required String uri, required DateTime performedAt, required MigrationStrategy migrationStrategy, required String oldScryfallId, String? newScryfallId, String? note})
const
Migration.fromJson(Map<String, dynamic> json)
Constructs a Migration object from JSON.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique ID for this card migration.
final
migrationStrategy → MigrationStrategy
A computer-readable indicator of the migration strategy.
final
newScryfallId → String?
The replacement id of the API card object if this is a MigrationStrategy.merge.
final
note → String?
A note left by the Scryfall team about this migration.
final
object → String
Constant discriminator for object type.
no setter
oldScryfallId → String
The id of the affected API Card object.
final
performedAt → DateTime
The date the migration was performed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String
The Scryfall URI for the current object.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this Migration object to JSON.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited